==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/TemplateRepository.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;


import java.util.ArrayList;
import java.util.List;
import org.hibernate.Session;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.hibernate.HibernateUtil;
import pt.digitalis.dif.model.utils.AbstractBeanRelationsAttributes;
import pt.digitalis.dif.model.utils.IBeanAttributesDataSet;

/**
 * TemplateRepository
* Generated on ORM Generator
* DIF build process for the Model layer
*
*/
@SuppressWarnings("serial")
public class TemplateRepository extends AbstractBeanRelationsAttributes implements java.io.Serializable, IBeanAttributesDataSet<TemplateRepository> {

    /** TemplateRepository attributes enumeration */
    public static class Fields
    {
        /** id column */
        public static final String ID ="id";
        /** name column */
        public static final String NAME ="name";
        /** language column */
        public static final String LANGUAGE ="language";
        /** content column */
        public static final String CONTENT ="content";

        /**
         * List of existing fields
         *
         * @return list of field names
         */
        public static List<String> values()
        {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("name");
            list.add("language");
            list.add("content");

            return list;
        }
    }

    /** Field attributes */
    public static TemplateRepositoryFieldAttributes FieldAttributes=new TemplateRepositoryFieldAttributes();

    /**
    * @return the field attributes definitions
    */
    @Override public TemplateRepositoryFieldAttributes getDefinitions()
    {
        return FieldAttributes;
    }

    /**
     * The Class Relations.
     */
    public class Relations extends AbstractBeanRelationsAttributes.AbstractRelations
    {

        /**
        * Instantiates a new relations.
        *
        * @param currentPath the current path
        */
        public Relations(String currentPath)
        {
            super(currentPath);
        }
        /**
         * the ID path.
         *
         * @return the path
         */
        public String ID()
        {
            return buildPath(Fields.ID);
        }
        /**
         * the NAME path.
         *
         * @return the path
         */
        public String NAME()
        {
            return buildPath(Fields.NAME);
        }
        /**
         * the LANGUAGE path.
         *
         * @return the path
         */
        public String LANGUAGE()
        {
            return buildPath(Fields.LANGUAGE);
        }
        /**
         * the CONTENT path.
         *
         * @return the path
         */
        public String CONTENT()
        {
            return buildPath(Fields.CONTENT);
        }
    }

    /** The dummy obj. */
    private static TemplateRepository dummyObj=new TemplateRepository();

    /**
     * Get TemplateRepository Relations .
     *
     * @return the relations
     */
    public static Relations FK()
    {
        return dummyObj.new Relations(null);
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public IDataSet<TemplateRepository> getDataSet()
    {
        return new HibernateDataSet<TemplateRepository>(TemplateRepository.class, HibernateUtil.getSessionFactory("DIFRepository"),
            TemplateRepository.getPKFieldListAsString(), TemplateRepository.FieldAttributes);
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public static IDataSet<TemplateRepository> getDataSetInstance()
    {
        return new TemplateRepository().getDataSet();
    }

    /**
    * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
    */
    @Override protected Object getAttributeNoGraphNavigation(String attributeName)
    {
        if("id".equalsIgnoreCase(attributeName))
            return id;
        if("name".equalsIgnoreCase(attributeName))
            return name;
        if("language".equalsIgnoreCase(attributeName))
            return language;
        if("content".equalsIgnoreCase(attributeName))
            return content;

        return null;
    }

    /**
    * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
    */
    public void setAttribute(String attributeName,Object attributeValue)
    {
        if("id".equalsIgnoreCase(attributeName))
            id =(Long)attributeValue;
        if("name".equalsIgnoreCase(attributeName))
            name =(String)attributeValue;
        if("language".equalsIgnoreCase(attributeName))
            language =(String)attributeValue;
        if("content".equalsIgnoreCase(attributeName))
            content =(String)attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** name private attribute */
    private String name;

    /** language private attribute */
    private String language;

    /** content private attribute */
    private String content;

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
     public synchronized static List<String> getPKFieldList()
     {
         if (pkFieldList == null)
         {
             pkFieldList = new ArrayList<String>();
             pkFieldList.add("id");
         }

         return pkFieldList;
     }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
     public static String getPKFieldListAsString()
     {
         StringBuffer buffer = new StringBuffer();

         for (int i = 0; i < getPKFieldList().size(); i++)
         {
             if (i != 0)
                 buffer.append(",");

             buffer.append(getPKFieldList().get(i));
         }

         return buffer.toString();
     }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
     @Override
     public String getAttributeAsString(String attributeName)
     {

        Object value = getAttribute(attributeName);

        if (value == null)
            return "";
        else {
            return value.toString().trim();
        }
     }

    // Constructors

    /**
     * default constructor
     */
    public TemplateRepository() {
    }


    /**
     * full constructor
	 *
     * @param name the name
     * @param language the language
     * @param content the content
     */
    public TemplateRepository(String name, String language, String content) {
        this.name = name;
        this.language = language;
        this.content = content;
    }

    // Property accessors
    
    /**       
     * id getter method
     *
     * @return id method
     */
    public Long getId() {
        return this.id;
    }
    
    /**       
     * id setter method
     *
     * @param id the id
     *
     * @return TemplateRepository modified instance
     */
    public TemplateRepository setId(Long id) {
        this.id = id;
        
        return this;
    }
    /**       
     * name getter method
     *
     * @return name method
     */
    public String getName() {
        return this.name;
    }
    
    /**       
     * name setter method
     *
     * @param name the name
     *
     * @return TemplateRepository modified instance
     */
    public TemplateRepository setName(String name) {
        this.name = name;
        
        return this;
    }
    /**       
     * language getter method
     *
     * @return language method
     */
    public String getLanguage() {
        return this.language;
    }
    
    /**       
     * language setter method
     *
     * @param language the language
     *
     * @return TemplateRepository modified instance
     */
    public TemplateRepository setLanguage(String language) {
        this.language = language;
        
        return this;
    }
    /**       
     * content getter method
     *
     * @return content method
     */
    public String getContent() {
        return this.content;
    }
    
    /**       
     * content setter method
     *
     * @param content the content
     *
     * @return TemplateRepository modified instance
     */
    public TemplateRepository setContent(String content) {
        this.content = content;
        
        return this;
    }

    /**
     * Creates a String representation of the TemplateRepository object
     *
     * @return the compiled String
     */
    @Override
    public String toString() {
	    StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");			
        buffer.append("name").append("='").append(getName()).append("' ");			
        buffer.append("language").append("='").append(getLanguage()).append("' ");			
        buffer.append("content").append("='").append(getContent()).append("' ");			
        buffer.append("]");
      
        return buffer.toString();
    }

    /**
     * Compares the String representation of the TemplateRepository object
     *
     * @param other The object to compare to
     *
     * @return true of the objects are equal
     */
    public boolean equals(TemplateRepository other) {
        	return this.toString().equals(other.toString());
    }
    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue) {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("name".equalsIgnoreCase(attributeName))
        	this.name = attributeValue;

        if ("language".equalsIgnoreCase(attributeName))
        	this.language = attributeValue;

        if ("content".equalsIgnoreCase(attributeName))
        	this.content = attributeValue;

    }


    /**
     * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
     *
     * @param session the session
     * @param id      the id
     *
     * @return the proxy
     */
    public static TemplateRepository getProxy(Session session, Long id)
    {
        return(TemplateRepository)session.load(TemplateRepository.class,id);
    }

    /**
    * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
    *
    * @param id      the id
    *
    * @return the proxy
    */
    public static TemplateRepository getProxy(Long id)
    {
        Session session = HibernateUtil.getSessionFactory("DIFRepository").getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        TemplateRepository result = (TemplateRepository)session.load(TemplateRepository.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }


    /**
     * Instanciates an Hibernate data object
     *
     * @param session the session
     * @param id      the id
     *
     * @return the instance
     */
    public static TemplateRepository getInstance(Session session, Long id)
    {
        return(TemplateRepository)session.get(TemplateRepository.class,id);
    }

    /**
    * Instanciates an Hibernate data object
    *
    * @param id      the id
    *
    * @return the instance
    */
    public static TemplateRepository getInstance(Long id)
    {
        Session session = HibernateUtil.getSessionFactory("DIFRepository").getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        TemplateRepository result = (TemplateRepository)session.get(TemplateRepository.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }

}

==> dif-database-repository-2.7.3-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/TemplateRepository.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;


import java.util.ArrayList;
import java.util.List;
import org.hibernate.Session;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.hibernate.HibernateUtil;
import pt.digitalis.dif.model.utils.AbstractBeanRelationsAttributes;
import pt.digitalis.dif.model.utils.IBeanAttributesDataSet;

/**
 * TemplateRepository
* Generated on ORM Generator
* DIF build process for the Model layer
*
*/
@SuppressWarnings("serial")
public class TemplateRepository extends AbstractBeanRelationsAttributes implements java.io.Serializable, IBeanAttributesDataSet<TemplateRepository> {

    /**
    * Constant with the session factory ID
    */
    public static String SESSION_FACTORY_NAME = "DIFRepository";

    /** TemplateRepository attributes enumeration */
    public static class Fields
    {
        /** id column */
        public static final String ID ="id";
        /** name column */
        public static final String NAME ="name";
        /** language column */
        public static final String LANGUAGE ="language";
        /** content column */
        public static final String CONTENT ="content";

        /**
         * List of existing fields
         *
         * @return list of field names
         */
        public static List<String> values()
        {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("name");
            list.add("language");
            list.add("content");

            return list;
        }
    }

    /** Field attributes */
    public static TemplateRepositoryFieldAttributes FieldAttributes=new TemplateRepositoryFieldAttributes();

    /**
    * @return the field attributes definitions
    */
    @Override public TemplateRepositoryFieldAttributes getDefinitions()
    {
        return FieldAttributes;
    }

    /**
     * The Class Relations.
     */
    public class Relations extends AbstractBeanRelationsAttributes.AbstractRelations
    {

        /**
        * Instantiates a new relations.
        *
        * @param currentPath the current path
        */
        public Relations(String currentPath)
        {
            super(currentPath);
        }
        /**
         * the ID path.
         *
         * @return the path
         */
        public String ID()
        {
            return buildPath(Fields.ID);
        }
        /**
         * the NAME path.
         *
         * @return the path
         */
        public String NAME()
        {
            return buildPath(Fields.NAME);
        }
        /**
         * the LANGUAGE path.
         *
         * @return the path
         */
        public String LANGUAGE()
        {
            return buildPath(Fields.LANGUAGE);
        }
        /**
         * the CONTENT path.
         *
         * @return the path
         */
        public String CONTENT()
        {
            return buildPath(Fields.CONTENT);
        }
    }

    /** The dummy obj. */
    private static TemplateRepository dummyObj=new TemplateRepository();

    /**
     * Get TemplateRepository Relations .
     *
     * @return the relations
     */
    public static Relations FK()
    {
        return dummyObj.new Relations(null);
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public IDataSet<TemplateRepository> getDataSet()
    {
        return getDataSetInstance();
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public static IDataSet<TemplateRepository> getDataSetInstance()
    {
        return new HibernateDataSet<TemplateRepository>(TemplateRepository.class, HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME),
            TemplateRepository.getPKFieldListAsString(), TemplateRepository.FieldAttributes);
    }

    /**
    * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
    */
    @Override protected Object getAttributeNoGraphNavigation(String attributeName)
    {
        if("id".equalsIgnoreCase(attributeName))
            return id;
        if("name".equalsIgnoreCase(attributeName))
            return name;
        if("language".equalsIgnoreCase(attributeName))
            return language;
        if("content".equalsIgnoreCase(attributeName))
            return content;

        return null;
    }

    /**
    * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
    */
    public void setAttribute(String attributeName,Object attributeValue)
    {
        if("id".equalsIgnoreCase(attributeName))
            id =(Long)attributeValue;
        if("name".equalsIgnoreCase(attributeName))
            name =(String)attributeValue;
        if("language".equalsIgnoreCase(attributeName))
            language =(String)attributeValue;
        if("content".equalsIgnoreCase(attributeName))
            content =(String)attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** name private attribute */
    private String name;

    /** language private attribute */
    private String language;

    /** content private attribute */
    private String content;

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
     public synchronized static List<String> getPKFieldList()
     {
         if (pkFieldList == null)
         {
             pkFieldList = new ArrayList<String>();
             pkFieldList.add("id");
         }

         return pkFieldList;
     }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
     public static String getPKFieldListAsString()
     {
         StringBuffer buffer = new StringBuffer();

         for (int i = 0; i < getPKFieldList().size(); i++)
         {
             if (i != 0)
                 buffer.append(",");

             buffer.append(getPKFieldList().get(i));
         }

         return buffer.toString();
     }

    /**
     * Gets description field.
     *
     * @return the description field
     */
    @Override
    public String getDescriptionField()
    {
        return FieldAttributes.getDescriptionField();
    }

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
    @Override
    public List<String> getPKFields()
    {
        return getPKFieldList();
    }

    /**
     * Is composite PK.
     *
     * @return the boolean
     */
    @Override
    public boolean isCompositePK()
    {
        return this.getPKFieldList().size() > 1;
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
     @Override
     public String getAttributeAsString(String attributeName)
     {
        if (attributeName.contains("."))
        {
            return this.getAttributeAsStringParseBeanPath(attributeName);
        }
        else
        {
            Object value = getAttribute(attributeName);

            if (value == null)
                return "";
            else {
                return value.toString().trim();
            }
        }
     }

    // Constructors

    /**
     * default constructor
     */
    public TemplateRepository() {
    }


    /**
     * full constructor
	 *
     * @param name the name
     * @param language the language
     * @param content the content
     */
    public TemplateRepository(String name, String language, String content) {
        this.name = name;
        this.language = language;
        this.content = content;
    }

    // Property accessors
    
    /**       
     * id getter method
     *
     * @return id method
     */
    public Long getId() {
        return this.id;
    }
    
    /**       
     * id setter method
     *
     * @param id the id
     *
     * @return TemplateRepository modified instance
     */
    public TemplateRepository setId(Long id) {
        this.id = id;
        
        return this;
    }
    /**       
     * name getter method
     *
     * @return name method
     */
    public String getName() {
        return this.name;
    }
    
    /**       
     * name setter method
     *
     * @param name the name
     *
     * @return TemplateRepository modified instance
     */
    public TemplateRepository setName(String name) {
        this.name = name;
        
        return this;
    }
    /**       
     * language getter method
     *
     * @return language method
     */
    public String getLanguage() {
        return this.language;
    }
    
    /**       
     * language setter method
     *
     * @param language the language
     *
     * @return TemplateRepository modified instance
     */
    public TemplateRepository setLanguage(String language) {
        this.language = language;
        
        return this;
    }
    /**       
     * content getter method
     *
     * @return content method
     */
    public String getContent() {
        return this.content;
    }
    
    /**       
     * content setter method
     *
     * @param content the content
     *
     * @return TemplateRepository modified instance
     */
    public TemplateRepository setContent(String content) {
        this.content = content;
        
        return this;
    }


    /**
     * Creates a String representation of the TemplateRepository object
     *
     * @return the compiled String
     */
    @Override
    public String toString() {
	    StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");			
        buffer.append("name").append("='").append(getName()).append("' ");			
        buffer.append("language").append("='").append(getLanguage()).append("' ");			
        buffer.append("content").append("='").append(getContent()).append("' ");			
        buffer.append("]");
      
        return buffer.toString();
    }

    /**
     * Compares the String representation of the TemplateRepository object
     *
     * @param other The object to compare to
     *
     * @return true of the objects are equal
     */
    public boolean equals(TemplateRepository other) {
        	return this.toString().equals(other.toString());
    }
    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue) {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("name".equalsIgnoreCase(attributeName))
        	this.name = attributeValue;

        if ("language".equalsIgnoreCase(attributeName))
        	this.language = attributeValue;

        if ("content".equalsIgnoreCase(attributeName))
        	this.content = attributeValue;

    }


    /**
     * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
     *
     * @param session the session
     * @param id      the id
     *
     * @return the proxy
     */
    public static TemplateRepository getProxy(Session session, Long id)
    {
        return(TemplateRepository)session.load(TemplateRepository.class,id);
    }

    /**
    * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
    *
    * @param id      the id
    *
    * @return the proxy
    */
    public static TemplateRepository getProxy(Long id)
    {
        Session session = HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME).getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        TemplateRepository result = (TemplateRepository)session.load(TemplateRepository.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }


    /**
     * Instanciates an Hibernate data object
     *
     * @param session the session
     * @param id      the id
     *
     * @return the instance
     */
    public static TemplateRepository getInstanceForSession(Session session, Long id)
    {
        return(TemplateRepository)session.get(TemplateRepository.class,id);
    }

    /**
    * Instanciates an Hibernate data object
    *
    * @param id      the id
    *
    * @return the instance
    */
    public static TemplateRepository getInstance(Long id)
    {
        Session session = HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME).getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        TemplateRepository result = (TemplateRepository)session.get(TemplateRepository.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }

}
